@@ -66,7 +66,7 @@ def _noneify(value):
 
 
 class CalTRACKUsagePerDayModelResults(object):
-    """ Contains information about the chosen model.
+    """Contains information about the chosen model.
 
     Attributes
     ----------
@@ -159,7 +159,7 @@ class CalTRACKUsagePerDayModelResults(object):
         )
 
     def json(self, with_candidates=False):
-        """ Return a JSON-serializable representation of this result.
+        """Return a JSON-serializable representation of this result.
 
         The output of this function can be converted to a serialized string
         with :any:`json.dumps`.
@@ -187,7 +187,7 @@ class CalTRACKUsagePerDayModelResults(object):
 
     @classmethod
     def from_json(cls, data):
-        """ Loads a JSON-serializable representation into the model state.
+        """Loads a JSON-serializable representation into the model state.
 
         The input of this function is a dict which can be the result
         of :any:`json.loads`.
@@ -195,27 +195,28 @@ class CalTRACKUsagePerDayModelResults(object):
 
         # "model" is a CalTRACKUsagePerDayCandidateModel that was serialized
         model = None
-        d = data.get('model')
+        d = data.get("model")
         if d:
             model = CalTRACKUsagePerDayCandidateModel.from_json(d)
 
         c = cls(
-            data.get('status'),
-            data.get('method_name'),
-            interval=data.get('interval'),
+            data.get("status"),
+            data.get("method_name"),
+            interval=data.get("interval"),
             model=model,
-            r_squared_adj=data.get('r_squared_adj'),
-            candidates=data.get('candidates'),
-            warnings=data.get('warnings'),
-            metadata=data.get('metadata'),
-            settings=data.get('settings'))
+            r_squared_adj=data.get("r_squared_adj"),
+            candidates=data.get("candidates"),
+            warnings=data.get("warnings"),
+            metadata=data.get("metadata"),
+            settings=data.get("settings"),
+        )
 
         # Note the metrics do not contain all the data needed
         # for reconstruction (like the input pandas) ...
-        d = data.get('avgs_metrics')
+        d = data.get("avgs_metrics")
         if d:
             c.avgs_metrics = ModelMetrics.from_json(d)
-        d = data.get('totals_metrics')
+        d = data.get("totals_metrics")
         if d:
             c.totals_metrics = ModelMetrics.from_json(d)
         return c
@@ -245,7 +246,7 @@ class CalTRACKUsagePerDayModelResults(object):
         candidate_alpha=None,
         temp_range=None,
     ):
-        """ Plot a model fit.
+        """Plot a model fit.
 
         Parameters
         ----------
@@ -292,7 +293,7 @@ class CalTRACKUsagePerDayModelResults(object):
 
 
 class CalTRACKUsagePerDayCandidateModel(object):
-    """ Contains information about a candidate model.
+    """Contains information about a candidate model.
 
     Attributes
     ----------
@@ -365,7 +366,7 @@ class CalTRACKUsagePerDayCandidateModel(object):
         )
 
     def json(self):
-        """ Return a JSON-serializable representation of this result.
+        """Return a JSON-serializable representation of this result.
 
         The output of this function can be converted to a serialized string
         with :any:`json.dumps`.
@@ -381,19 +382,20 @@ class CalTRACKUsagePerDayCandidateModel(object):
 
     @classmethod
     def from_json(cls, data):
-        """ Loads a JSON-serializable representation into the model state.
+        """Loads a JSON-serializable representation into the model state.
 
         The input of this function is a dict which can be the result
         of :any:`json.loads`.
         """
 
         c = cls(
-            data.get('model_type'),
-            data.get('formula'),
-            data.get('status'),
-            model_params=data.get('model_params'),
-            r_squared_adj=data.get('r_squared_adj'),
-            warnings=data.get('warnings'))
+            data.get("model_type"),
+            data.get("formula"),
+            data.get("status"),
+            model_params=data.get("model_params"),
+            r_squared_adj=data.get("r_squared_adj"),
+            warnings=data.get("warnings"),
+        )
 
         return c
 
@@ -405,8 +407,7 @@ class CalTRACKUsagePerDayCandidateModel(object):
         with_design_matrix=False,
         **kwargs
     ):
-        """ Predict
-        """
+        """Predict"""
         return caltrack_usage_per_day_predict(
             self.model_type,
             self.model_params,
@@ -427,8 +428,7 @@ class CalTRACKUsagePerDayCandidateModel(object):
         alpha=None,
         **kwargs
     ):
-        """ Plot
-        """
+        """Plot"""
         return plot_caltrack_candidate(
             self,
             best=best,
@@ -442,7 +442,7 @@ class CalTRACKUsagePerDayCandidateModel(object):
 
 
 class DataSufficiency(object):
-    """ Contains the result of a data sufficiency check.
+    """Contains the result of a data sufficiency check.
 
     Attributes
     ----------
@@ -487,7 +487,7 @@ class DataSufficiency(object):
         )
 
     def json(self):
-        """ Return a JSON-serializable representation of this result.
+        """Return a JSON-serializable representation of this result.
 
         The output of this function can be converted to a serialized string
         with :any:`json.dumps`.
@@ -518,7 +518,7 @@ def _caltrack_predict_design_matrix(
     input_averages=False,
     output_averages=False,
 ):
-    """ An internal CalTRACK predict method for use with a design matrix of the form
+    """An internal CalTRACK predict method for use with a design matrix of the form
     used in model fitting.
 
     Given a set model type, parameters, and daily temperatures, return model
@@ -646,7 +646,7 @@ def caltrack_usage_per_day_predict(
     with_disaggregated=False,
     with_design_matrix=False,
 ):
-    """ CalTRACK predict method.
+    """CalTRACK predict method.
 
     Given a model type, parameters, hourly temperatures, a
     :any:`pandas.DatetimeIndex` index over which to predict meter usage,
@@ -781,7 +781,7 @@ def caltrack_usage_per_day_predict(
 def get_too_few_non_zero_degree_day_warning(
     model_type, balance_point, degree_day_type, degree_days, minimum_non_zero
 ):
-    """ Return an empty list or a single warning wrapped in a list regarding
+    """Return an empty list or a single warning wrapped in a list regarding
     non-zero degree days for a set of degree days.
 
     Parameters
@@ -842,7 +842,7 @@ def get_total_degree_day_too_low_warning(
     period_days,
     minimum_total,
 ):
-    """ Return an empty list or a single warning wrapped in a list regarding
+    """Return an empty list or a single warning wrapped in a list regarding
     the total summed degree day values.
 
     Parameters
@@ -899,7 +899,7 @@ def get_total_degree_day_too_low_warning(
 
 
 def get_parameter_negative_warning(model_type, model_params, parameter):
-    """ Return an empty list or a single warning wrapped in a list indicating
+    """Return an empty list or a single warning wrapped in a list indicating
     whether model parameter is negative.
 
     Parameters
@@ -939,7 +939,7 @@ def get_parameter_negative_warning(model_type, model_params, parameter):
 def get_parameter_p_value_too_high_warning(
     model_type, model_params, parameter, p_value, maximum_p_value
 ):
-    """ Return an empty list or a single warning wrapped in a list indicating
+    """Return an empty list or a single warning wrapped in a list indicating
     whether model parameter p-value is too high.
 
     Parameters
@@ -986,7 +986,7 @@ def get_parameter_p_value_too_high_warning(
 
 
 def get_fit_failed_candidate_model(model_type, formula):
-    """ Return a Candidate model that indicates the fitting routine failed.
+    """Return a Candidate model that indicates the fitting routine failed.
 
     Parameters
     ----------
@@ -1016,7 +1016,7 @@ def get_fit_failed_candidate_model(model_type, formula):
 
 
 def get_intercept_only_candidate_models(data, weights_col):
-    """ Return a list of a single candidate intercept-only model.
+    """Return a list of a single candidate intercept-only model.
 
     Parameters
     ----------
@@ -1086,7 +1086,7 @@ def get_single_cdd_only_candidate_model(
     weights_col,
     balance_point,
 ):
-    """ Return a single candidate cdd-only model for a particular balance
+    """Return a single candidate cdd-only model for a particular balance
     point.
 
     Parameters
@@ -1202,7 +1202,7 @@ def get_single_cdd_only_candidate_model(
 def get_cdd_only_candidate_models(
     data, minimum_non_zero_cdd, minimum_total_cdd, beta_cdd_maximum_p_value, weights_col
 ):
-    """ Return a list of all possible candidate cdd-only models.
+    """Return a list of all possible candidate cdd-only models.
 
     Parameters
     ----------
@@ -1250,7 +1250,7 @@ def get_single_hdd_only_candidate_model(
     weights_col,
     balance_point,
 ):
-    """ Return a single candidate hdd-only model for a particular balance
+    """Return a single candidate hdd-only model for a particular balance
     point.
 
     Parameters
@@ -1419,7 +1419,7 @@ def get_single_cdd_hdd_candidate_model(
     cooling_balance_point,
     heating_balance_point,
 ):
-    """ Return and fit a single candidate cdd_hdd model for a particular selection
+    """Return and fit a single candidate cdd_hdd model for a particular selection
     of cooling balance point and heating balance point
 
     Parameters
@@ -1584,7 +1584,7 @@ def get_cdd_hdd_candidate_models(
     beta_hdd_maximum_p_value,
     weights_col,
 ):
-    """ Return a list of candidate cdd_hdd models for a particular selection
+    """Return a list of candidate cdd_hdd models for a particular selection
     of cooling balance point and heating balance point
 
     Parameters
@@ -1646,7 +1646,7 @@ def get_cdd_hdd_candidate_models(
 
 
 def select_best_candidate(candidate_models):
-    """ Select and return the best candidate model based on r-squared and
+    """Select and return the best candidate model based on r-squared and
     qualification.
 
     Parameters
@@ -1707,7 +1707,7 @@ def fit_caltrack_usage_per_day_model(
     fit_hdd_only=True,
     fit_cdd_hdd=True,
 ):
-    """ CalTRACK daily and billing methods using a usage-per-day modeling
+    """CalTRACK daily and billing methods using a usage-per-day modeling
     strategy.
 
     Parameters
@@ -2233,7 +2233,7 @@ def plot_caltrack_candidate(
     alpha=None,
     **kwargs
 ):
-    """ Plot a CalTRACK candidate model.
+    """Plot a CalTRACK candidate model.
 
     Parameters
     ----------
